@@ -42,11 +42,14 @@ namespace aria2 {
 
 class DHTFindNodeReplyMessage:public DHTResponseMessage {
 private:
-  std::vector<SharedHandle<DHTNode> > _closestKNodes;
+  int family_;
+
+  std::vector<SharedHandle<DHTNode> > closestKNodes_;
 protected:
   virtual std::string toStringOptional() const;
 public:
-  DHTFindNodeReplyMessage(const SharedHandle<DHTNode>& localNode,
+  DHTFindNodeReplyMessage(int family,
+                          const SharedHandle<DHTNode>& localNode,
                           const SharedHandle<DHTNode>& remoteNode,
                           const std::string& transactionID);
 
@@ -54,15 +57,15 @@ public:
 
   virtual void doReceivedAction();
 
-  virtual BDE getResponse();
+  virtual SharedHandle<Dict> getResponse();
   
-  virtual std::string getMessageType() const;
+  virtual const std::string& getMessageType() const;
 
-  virtual void validate() const;
+  virtual void accept(DHTMessageCallback* callback);
 
   const std::vector<SharedHandle<DHTNode> >& getClosestKNodes() const
   {
-    return _closestKNodes;
+    return closestKNodes_;
   }
 
   void setClosestKNodes
@@ -71,6 +74,8 @@ public:
   static const std::string FIND_NODE;
   
   static const std::string NODES;
+  
+  static const std::string NODES6;
 };
 
 } // namespace aria2
