@@ -42,7 +42,7 @@ namespace aria2 {
 
 class DHTPingReplyMessage:public DHTResponseMessage {
 private:
-  unsigned char _id[DHT_ID_LENGTH];
+  unsigned char id_[DHT_ID_LENGTH];
 public:
   DHTPingReplyMessage(const SharedHandle<DHTNode>& localNode,
                       const SharedHandle<DHTNode>& remoteNode,
@@ -53,15 +53,15 @@ public:
 
   virtual void doReceivedAction();
 
-  virtual BDE getResponse();
+  virtual SharedHandle<Dict> getResponse();
 
-  virtual std::string getMessageType() const;
+  virtual const std::string& getMessageType() const;
 
-  virtual void validate() const;
+  virtual void accept(DHTMessageCallback* callback);
 
   const unsigned char* getRemoteID()
   {
-    return _id;
+    return id_;
   }
 
   static const std::string PING;
