@@ -51,106 +51,114 @@
 namespace aria2 {
 
 DefaultBtRequestFactory::DefaultBtRequestFactory():
-  cuid(0),
-  _logger(LogFactory::getInstance())
+  logger_(LogFactory::getInstance())
 {
-  if(_logger->debug()) {
-    _logger->debug("DefaultBtRequestFactory::instantiated");
+  if(logger_->debug()) {
+    logger_->debug("DefaultBtRequestFactory::instantiated");
   }
 }
 
 DefaultBtRequestFactory::~DefaultBtRequestFactory()
 {
-  if(_logger->debug()) {
-    _logger->debug("DefaultBtRequestFactory::deleted");
+  if(logger_->debug()) {
+    logger_->debug("DefaultBtRequestFactory::deleted");
   }
 }
 
-void DefaultBtRequestFactory::addTargetPiece(const PieceHandle& piece)
+void DefaultBtRequestFactory::addTargetPiece(const SharedHandle<Piece>& piece)
 {
-  pieces.push_back(piece);
+  pieces_.push_back(piece);
 }
 
+namespace {
 class AbortCompletedPieceRequest
 {
 private:
-  WeakHandle<BtMessageDispatcher> _dispatcher;
+  WeakHandle<BtMessageDispatcher> dispatcher_;
 public:
   AbortCompletedPieceRequest(const WeakHandle<BtMessageDispatcher>& dispatcher):
-    _dispatcher(dispatcher) {}
+    dispatcher_(dispatcher) {}
 
   void operator()(const SharedHandle<Piece>& piece)
   {
     if(piece->pieceComplete()) {
-      _dispatcher->doAbortOutstandingRequestAction(piece);
+      dispatcher_->doAbortOutstandingRequestAction(piece);
     }
   }
 };
+}
 
 void DefaultBtRequestFactory::removeCompletedPiece() {
-  std::for_each(pieces.begin(), pieces.end(),
-                AbortCompletedPieceRequest(dispatcher));
-  pieces.erase(std::remove_if(pieces.begin(), pieces.end(),
+  std::for_each(pieces_.begin(), pieces_.end(),
+                AbortCompletedPieceRequest(dispatcher_));
+  pieces_.erase(std::remove_if(pieces_.begin(), pieces_.end(),
                               mem_fun_sh(&Piece::pieceComplete)),
-               pieces.end());
+               pieces_.end());
 }
 
-void DefaultBtRequestFactory::removeTargetPiece(const PieceHandle& piece) {
-  pieces.erase(std::remove(pieces.begin(), pieces.end(), piece),
-               pieces.end());
-  dispatcher->doAbortOutstandingRequestAction(piece);
-  _pieceStorage->cancelPiece(piece);
+void DefaultBtRequestFactory::removeTargetPiece
+(const SharedHandle<Piece>& piece)
+{
+  pieces_.erase(std::remove(pieces_.begin(), pieces_.end(), piece),
+               pieces_.end());
+  dispatcher_->doAbortOutstandingRequestAction(piece);
+  pieceStorage_->cancelPiece(piece);
 }
 
+namespace {
 class ProcessChokedPiece {
 private:
-  SharedHandle<Peer> _peer;
-  WeakHandle<PieceStorage> _pieceStorage;
+  SharedHandle<Peer> peer_;
+  WeakHandle<PieceStorage> pieceStorage_;
 public:
   ProcessChokedPiece(const SharedHandle<Peer>& peer,
                      const WeakHandle<PieceStorage>& pieceStorage):
-    _peer(peer),
-    _pieceStorage(pieceStorage) {}
+    peer_(peer),
+    pieceStorage_(pieceStorage) {}
 
   void operator()(const SharedHandle<Piece>& piece)
   {
-    if(!_peer->isInPeerAllowedIndexSet(piece->getIndex())) {
-      _pieceStorage->cancelPiece(piece);
+    if(!peer_->isInPeerAllowedIndexSet(piece->getIndex())) {
+      pieceStorage_->cancelPiece(piece);
     }
   }
 };
+}
 
+namespace {
 class FindChokedPiece {
 private:
-  SharedHandle<Peer> _peer;
+  SharedHandle<Peer> peer_;
 public:
-  FindChokedPiece(const SharedHandle<Peer>& peer):_peer(peer) {}
+  FindChokedPiece(const SharedHandle<Peer>& peer):peer_(peer) {}
 
   bool operator()(const SharedHandle<Piece>& piece)
   {
-    return !_peer->isInPeerAllowedIndexSet(piece->getIndex());
+    return !peer_->isInPeerAllowedIndexSet(piece->getIndex());
   }
 };
+}
 
 void DefaultBtRequestFactory::doChokedAction()
 {
-  std::for_each(pieces.begin(), pieces.end(),
-                ProcessChokedPiece(peer, _pieceStorage));
-  pieces.erase(std::remove_if(pieces.begin(), pieces.end(),
-                              FindChokedPiece(peer)),
-               pieces.end());
+  std::for_each(pieces_.begin(), pieces_.end(),
+                ProcessChokedPiece(peer_, pieceStorage_));
+  pieces_.erase(std::remove_if(pieces_.begin(), pieces_.end(),
+                              FindChokedPiece(peer_)),
+               pieces_.end());
 }
 
 void DefaultBtRequestFactory::removeAllTargetPiece() {
-  for(Pieces::iterator itr = pieces.begin(); itr != pieces.end(); ++itr) {
-    dispatcher->doAbortOutstandingRequestAction(*itr);
-    _pieceStorage->cancelPiece(*itr);
+  for(std::deque<SharedHandle<Piece> >::iterator itr = pieces_.begin(),
+        eoi = pieces_.end(); itr != eoi; ++itr) {
+    dispatcher_->doAbortOutstandingRequestAction(*itr);
+    pieceStorage_->cancelPiece(*itr);
   }
-  pieces.clear();
+  pieces_.clear();
 }
 
 void DefaultBtRequestFactory::createRequestMessages
-(std::deque<SharedHandle<BtMessage> >& requests, size_t max)
+(std::vector<SharedHandle<BtMessage> >& requests, size_t max)
 {
   if(requests.size() >= max) {
     return;
@@ -158,22 +166,22 @@ void DefaultBtRequestFactory::createRequestMessages
   size_t getnum = max-requests.size();
   std::vector<size_t> blockIndexes;
   blockIndexes.reserve(getnum);
-  for(Pieces::iterator itr = pieces.begin();
-      itr != pieces.end() && getnum; ++itr) {
+  for(std::deque<SharedHandle<Piece> >::iterator itr = pieces_.begin(),
+        eoi = pieces_.end(); itr != eoi && getnum; ++itr) {
     SharedHandle<Piece>& piece = *itr;
     if(piece->getMissingUnusedBlockIndex(blockIndexes, getnum)) {
       getnum -= blockIndexes.size();
-      for(std::vector<size_t>::const_iterator i = blockIndexes.begin();
-          i != blockIndexes.end(); ++i) {
-        if(_logger->debug()) {
-          _logger->debug("Creating RequestMessage index=%u, begin=%u,"
+      for(std::vector<size_t>::const_iterator i = blockIndexes.begin(),
+            eoi2 = blockIndexes.end(); i != eoi2; ++i) {
+        if(logger_->debug()) {
+          logger_->debug("Creating RequestMessage index=%u, begin=%u,"
                          " blockIndex=%u",
                          piece->getIndex(),
                          (*i)*piece->getBlockLength(),
                          (*i));
         }
         requests.push_back
-          (messageFactory->createRequestMessage(piece, *i));
+          (messageFactory_->createRequestMessage(piece, *i));
       }
       blockIndexes.clear();
     }
@@ -181,17 +189,17 @@ void DefaultBtRequestFactory::createRequestMessages
 }
 
 void DefaultBtRequestFactory::createRequestMessagesOnEndGame
-(std::deque<SharedHandle<BtMessage> >& requests, size_t max)
+(std::vector<SharedHandle<BtMessage> >& requests, size_t max)
 {
-  for(Pieces::iterator itr = pieces.begin();
-      itr != pieces.end() && requests.size() < max; ++itr) {
-    PieceHandle& piece = *itr;
+  for(std::deque<SharedHandle<Piece> >::iterator itr = pieces_.begin(),
+        eoi = pieces_.end(); itr != eoi && requests.size() < max; ++itr) {
+    SharedHandle<Piece>& piece = *itr;
     const size_t mislen = piece->getBitfieldLength();
     array_ptr<unsigned char> misbitfield(new unsigned char[mislen]);
 
     piece->getAllMissingBlockIndexes(misbitfield, mislen);
 
-    std::deque<size_t> missingBlockIndexes;
+    std::vector<size_t> missingBlockIndexes;
     size_t blockIndex = 0;
     for(size_t i = 0; i < mislen; ++i) {
       unsigned char bits = misbitfield[i];
@@ -204,74 +212,80 @@ void DefaultBtRequestFactory::createRequestMessagesOnEndGame
     }
     std::random_shuffle(missingBlockIndexes.begin(), missingBlockIndexes.end(),
                         *(SimpleRandomizer::getInstance().get()));
-    for(std::deque<size_t>::const_iterator bitr = missingBlockIndexes.begin();
-        bitr != missingBlockIndexes.end() && requests.size() < max; bitr++) {
+    for(std::vector<size_t>::const_iterator bitr = missingBlockIndexes.begin(),
+          eoi2 = missingBlockIndexes.end();
+        bitr != eoi2 && requests.size() < max; ++bitr) {
       const size_t& blockIndex = *bitr;
-      if(!dispatcher->isOutstandingRequest(piece->getIndex(),
+      if(!dispatcher_->isOutstandingRequest(piece->getIndex(),
                                            blockIndex)) {
-        if(_logger->debug()) {
-          _logger->debug("Creating RequestMessage index=%u, begin=%u,"
+        if(logger_->debug()) {
+          logger_->debug("Creating RequestMessage index=%u, begin=%u,"
                          " blockIndex=%u",
                          piece->getIndex(),
                          blockIndex*piece->getBlockLength(),
                          blockIndex);
         }
-        requests.push_back(messageFactory->createRequestMessage(piece, blockIndex));
+        requests.push_back(messageFactory_->createRequestMessage
+                           (piece, blockIndex));
       }
     }
   }
 }
 
+namespace {
 class CountMissingBlock
 {
 private:
-  size_t _numMissingBlock;
+  size_t numMissingBlock_;
 public:
-  CountMissingBlock():_numMissingBlock(0) {}
+  CountMissingBlock():numMissingBlock_(0) {}
 
   size_t getNumMissingBlock()
   {
-    return _numMissingBlock;
+    return numMissingBlock_;
   }
 
   void operator()(const SharedHandle<Piece>& piece)
   {
-    _numMissingBlock += piece->countMissingBlock();
+    numMissingBlock_ += piece->countMissingBlock();
   }
 };
+}
 
 size_t DefaultBtRequestFactory::countMissingBlock()
 {
-  return std::for_each(pieces.begin(), pieces.end(),
+  return std::for_each(pieces_.begin(), pieces_.end(),
                        CountMissingBlock()).getNumMissingBlock();
 }
 
 void DefaultBtRequestFactory::getTargetPieceIndexes
-(std::deque<size_t>& indexes) const
+(std::vector<size_t>& indexes) const
 {
-  std::transform(pieces.begin(), pieces.end(), std::back_inserter(indexes),
+  std::transform(pieces_.begin(), pieces_.end(), std::back_inserter(indexes),
                  mem_fun_sh(&Piece::getIndex));
 }
 
 void DefaultBtRequestFactory::setPieceStorage
 (const SharedHandle<PieceStorage>& pieceStorage)
 {
-  _pieceStorage = pieceStorage;
+  pieceStorage_ = pieceStorage;
 }
 
 void DefaultBtRequestFactory::setPeer(const SharedHandle<Peer>& peer)
 {
-  this->peer = peer;
+  peer_ = peer;
 }
 
-void DefaultBtRequestFactory::setBtMessageDispatcher(const WeakHandle<BtMessageDispatcher>& dispatcher)
+void DefaultBtRequestFactory::setBtMessageDispatcher
+(const WeakHandle<BtMessageDispatcher>& dispatcher)
 {
-  this->dispatcher = dispatcher;
+  dispatcher_ = dispatcher;
 }
 
-void DefaultBtRequestFactory::setBtMessageFactory(const WeakHandle<BtMessageFactory>& factory)
+void DefaultBtRequestFactory::setBtMessageFactory
+(const WeakHandle<BtMessageFactory>& factory)
 {
-  this->messageFactory = factory;
+  messageFactory_ = factory;
 }
 
 } // namespace aria2
