@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,35 +36,14 @@
 #define _D_FILE_ALLOCATION_MAN_H_
 
 #include "common.h"
+#include "SequentialPicker.h"
+
+namespace aria2 {
 
 class FileAllocationEntry;
-typedef SharedHandle<FileAllocationEntry> FileAllocationEntryHandle;
-typedef deque<FileAllocationEntryHandle> FileAllocationEntries;
 
-class FileAllocationMan {
-private:
-  FileAllocationEntries _fileAllocationEntries;
-  FileAllocationEntryHandle _currentFileAllocationEntry;
-public:
-  FileAllocationMan();
+typedef SequentialPicker<FileAllocationEntry> FileAllocationMan;
 
-  ~FileAllocationMan();
-
-  bool isFileAllocationBeingExecuted() const;
-
-  FileAllocationEntryHandle getCurrentFileAllocationEntry();
-
-  void markCurrentFileAllocationEntryDone();
-
-  bool nextFileAllocationEntryExists() const;
-
-  FileAllocationEntryHandle popNextFileAllocationEntry();
-
-  void pushFileAllocationEntry(const FileAllocationEntryHandle& entry);
-
-  int32_t countFileAllocationEntryInQueue() const;
-};
-
-typedef SharedHandle<FileAllocationMan> FileAllocationManHandle;
+} // namespace aria2
 
 #endif // _D_FILE_ALLOCATION_MAN_H_
