@@ -497,7 +497,7 @@ public:
     std::stringstream s;
     std::copy(validParamValues_.begin(), validParamValues_.end(),
               std::ostream_iterator<std::string>(s, ","));
-    return util::trim(s.str(), ", ");
+    return util::strip(s.str(), ", ");
   }
 };
 
