@@ -55,16 +55,16 @@ public:
     RECEIVER_WAIT_HANDSHAKE,
     WIRED};
 private:
-  RequestGroup* _requestGroup;
+  RequestGroup* requestGroup_;
 
-  SharedHandle<BtRuntime> _btRuntime;
+  SharedHandle<BtRuntime> btRuntime_;
 
-  SharedHandle<PieceStorage> _pieceStorage;
+  SharedHandle<PieceStorage> pieceStorage_;
 
-  SharedHandle<PeerStorage> _peerStorage;
+  SharedHandle<PeerStorage> peerStorage_;
 
-  Seq sequence;
-  SharedHandle<BtInteractive> btInteractive;
+  Seq sequence_;
+  SharedHandle<BtInteractive> btInteractive_;
 
   const SharedHandle<Option>& getOption() const;
 protected:
@@ -74,7 +74,7 @@ protected:
   virtual void onFailure();
   virtual bool exitBeforeExecute();
 public:
-  PeerInteractionCommand(int32_t cuid,
+  PeerInteractionCommand(cuid_t cuid,
                          RequestGroup* requestGroup,
                          const SharedHandle<Peer>& peer,
                          DownloadEngine* e,
