@@ -58,6 +58,20 @@ XmlRpcMethodFactory::create(const std::string& methodName)
   }
   else if(methodName == RemoveXmlRpcMethod::getMethodName()) {
     return SharedHandle<XmlRpcMethod>(new RemoveXmlRpcMethod());
+  } else if(methodName == PauseXmlRpcMethod::getMethodName()) {
+    return SharedHandle<XmlRpcMethod>(new PauseXmlRpcMethod());
+  } else if(methodName == ForcePauseXmlRpcMethod::getMethodName()) {
+    return SharedHandle<XmlRpcMethod>(new ForcePauseXmlRpcMethod());
+  } else if(methodName == PauseAllXmlRpcMethod::getMethodName()) {
+    return SharedHandle<XmlRpcMethod>(new PauseAllXmlRpcMethod());
+  } else if(methodName == ForcePauseAllXmlRpcMethod::getMethodName()) {
+    return SharedHandle<XmlRpcMethod>(new ForcePauseAllXmlRpcMethod());
+  } else if(methodName == UnpauseXmlRpcMethod::getMethodName()) {
+    return SharedHandle<XmlRpcMethod>(new UnpauseXmlRpcMethod());
+  } else if(methodName == UnpauseAllXmlRpcMethod::getMethodName()) {
+    return SharedHandle<XmlRpcMethod>(new UnpauseAllXmlRpcMethod());
+  } else if(methodName == ForceRemoveXmlRpcMethod::getMethodName()) {
+    return SharedHandle<XmlRpcMethod>(new ForceRemoveXmlRpcMethod());
   } else if(methodName == ChangePositionXmlRpcMethod::getMethodName()) {
     return SharedHandle<XmlRpcMethod>(new ChangePositionXmlRpcMethod());
   } else if(methodName == TellStatusXmlRpcMethod::getMethodName()) {
@@ -71,6 +85,8 @@ XmlRpcMethodFactory::create(const std::string& methodName)
   else if(methodName == GetPeersXmlRpcMethod::getMethodName()) {
     return SharedHandle<XmlRpcMethod>(new GetPeersXmlRpcMethod());
 #endif // ENABLE_BITTORRENT
+  } else if(methodName == GetServersXmlRpcMethod::getMethodName()) {
+    return SharedHandle<XmlRpcMethod>(new GetServersXmlRpcMethod());
   } else if(methodName == TellActiveXmlRpcMethod::getMethodName()) {
     return SharedHandle<XmlRpcMethod>(new TellActiveXmlRpcMethod());
   } else if(methodName == TellWaitingXmlRpcMethod::getMethodName()) {
@@ -79,6 +95,8 @@ XmlRpcMethodFactory::create(const std::string& methodName)
     return SharedHandle<XmlRpcMethod>(new TellStoppedXmlRpcMethod());
   } else if(methodName == GetOptionXmlRpcMethod::getMethodName()) {
     return SharedHandle<XmlRpcMethod>(new GetOptionXmlRpcMethod());
+  } else if(methodName == ChangeUriXmlRpcMethod::getMethodName()) {
+    return SharedHandle<XmlRpcMethod>(new ChangeUriXmlRpcMethod());
   } else if(methodName == ChangeOptionXmlRpcMethod::getMethodName()) {
     return SharedHandle<XmlRpcMethod>(new ChangeOptionXmlRpcMethod());
   } else if(methodName == GetGlobalOptionXmlRpcMethod::getMethodName()) {
@@ -91,6 +109,10 @@ XmlRpcMethodFactory::create(const std::string& methodName)
     return SharedHandle<XmlRpcMethod>(new GetVersionXmlRpcMethod());
   } else if(methodName == GetSessionInfoXmlRpcMethod::getMethodName()) {
     return SharedHandle<XmlRpcMethod>(new GetSessionInfoXmlRpcMethod());
+  } else if(methodName == ShutdownXmlRpcMethod::getMethodName()) {
+    return SharedHandle<XmlRpcMethod>(new ShutdownXmlRpcMethod());
+  } else if(methodName == ForceShutdownXmlRpcMethod::getMethodName()) {
+    return SharedHandle<XmlRpcMethod>(new ForceShutdownXmlRpcMethod());
   } else if(methodName == SystemMulticallXmlRpcMethod::getMethodName()) {
     return SharedHandle<XmlRpcMethod>(new SystemMulticallXmlRpcMethod());
   } else {
