@@ -1,11 +1,16 @@
 #include "IteratableChecksumValidator.h"
-#include "SingleFileDownloadContext.h"
+
+#include <cppunit/extensions/HelperMacros.h>
+
+#include "DownloadContext.h"
 #include "DefaultPieceStorage.h"
 #include "Option.h"
 #include "DiskAdaptor.h"
-#include <cppunit/extensions/HelperMacros.h>
+#include "FileEntry.h"
+#include "PieceSelector.h"
+#include "messageDigest.h"
 
-using namespace std;
+namespace aria2 {
 
 class IteratableChecksumValidatorTest:public CppUnit::TestFixture {
 
@@ -28,11 +33,11 @@ CPPUNIT_TEST_SUITE_REGISTRATION( IteratableChecksumValidatorTest );
 
 void IteratableChecksumValidatorTest::testValidate() {
   Option option;
-  SingleFileDownloadContextHandle dctx =
-    new SingleFileDownloadContext(100, 250, "chunkChecksumTestFile250.txt");
+  SharedHandle<DownloadContext> dctx
+    (new DownloadContext(100, 250, "chunkChecksumTestFile250.txt"));
   dctx->setChecksum("898a81b8e0181280ae2ee1b81e269196d91e869a");
-  dctx->setChecksumHashAlgo("sha1");
-  DefaultPieceStorageHandle ps = new DefaultPieceStorage(dctx, &option);
+  dctx->setChecksumHashAlgo(MessageDigestContext::SHA1);
+  SharedHandle<DefaultPieceStorage> ps(new DefaultPieceStorage(dctx, &option));
   ps->initStorage();
   ps->getDiskAdaptor()->openFile();
 
@@ -47,11 +52,11 @@ void IteratableChecksumValidatorTest::testValidate() {
 
 void IteratableChecksumValidatorTest::testValidate_fail() {
   Option option;
-  SingleFileDownloadContextHandle dctx =
-    new SingleFileDownloadContext(100, 250, "chunkChecksumTestFile250.txt");
-  dctx->setChecksum(string(40, '0')); // set wrong checksum
-  dctx->setChecksumHashAlgo("sha1");
-  DefaultPieceStorageHandle ps = new DefaultPieceStorage(dctx, &option);
+  SharedHandle<DownloadContext> dctx
+    (new DownloadContext(100, 250, "chunkChecksumTestFile250.txt"));
+  dctx->setChecksum(std::string(40, '0')); // set wrong checksum
+  dctx->setChecksumHashAlgo(MessageDigestContext::SHA1);
+  SharedHandle<DefaultPieceStorage> ps(new DefaultPieceStorage(dctx, &option));
   ps->initStorage();
   ps->getDiskAdaptor()->openFile();
 
@@ -64,3 +69,5 @@ void IteratableChecksumValidatorTest::testValidate_fail() {
 
   CPPUNIT_ASSERT(!ps->downloadFinished());
 }
+
+} // namespace aria2
