@@ -86,8 +86,8 @@ void MetalinkProcessorTest::testParseFileV4()
   SharedHandle<MetalinkEntry> e;
   SharedHandle<MetalinkResource> r;
   SharedHandle<MetalinkMetaurl> mu;
-  CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
-  e = m->entries[0];
+  CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
+  e = m->getEntries()[0];
   CPPUNIT_ASSERT_EQUAL(std::string("example.ext"), e->getPath());
   CPPUNIT_ASSERT_EQUAL((uint64_t)786430LL, e->getLength());
   CPPUNIT_ASSERT_EQUAL(-1, e->maxConnections);
@@ -95,10 +95,11 @@ void MetalinkProcessorTest::testParseFileV4()
   CPPUNIT_ASSERT_EQUAL(std::string("0beec7b5ea3f0fdbc95d0dd47f3c5bc275da8a33"),
 		       e->checksum->getMessageDigest());
   CPPUNIT_ASSERT(!e->checksum.isNull());
-  CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), e->checksum->getAlgo());
+  CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1, e->checksum->getAlgo());
   CPPUNIT_ASSERT(!e->chunkChecksum.isNull());
   if(MessageDigestContext::supports(MessageDigestContext::SHA256)) {
-    CPPUNIT_ASSERT_EQUAL(std::string("sha-256"), e->chunkChecksum->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA256,
+                         e->chunkChecksum->getAlgo());
     CPPUNIT_ASSERT_EQUAL((size_t)262144, e->chunkChecksum->getChecksumLength());
     CPPUNIT_ASSERT_EQUAL((size_t)3, e->chunkChecksum->countChecksum());
     CPPUNIT_ASSERT_EQUAL(std::string("0245178074fd042e19b7c3885b360fc21064b30e73f5626c7e3b005d048069c5"),
@@ -108,7 +109,8 @@ void MetalinkProcessorTest::testParseFileV4()
     CPPUNIT_ASSERT_EQUAL(std::string("37290d74ac4d186e3a8e5785d259d2ec04fac91ae28092e7620ec8bc99e830aa"),
                          e->chunkChecksum->getChecksum(2));
   } else {
-    CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), e->chunkChecksum->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1,
+                         e->chunkChecksum->getAlgo());
     CPPUNIT_ASSERT_EQUAL((size_t)262144, e->chunkChecksum->getChecksumLength());
     CPPUNIT_ASSERT_EQUAL((size_t)3, e->chunkChecksum->countChecksum());
     CPPUNIT_ASSERT_EQUAL
@@ -164,7 +166,7 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
       "</metalink>";
     dw->setString(StringFormat(tmpl, "foo").str());
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     // empty name
     dw->setString(StringFormat(tmpl, "").str());
@@ -202,15 +204,15 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
 
     dw->setString(StringFormat(tmpl, "1").str());
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     dw->setString(StringFormat(tmpl, "100").str());
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     dw->setString(StringFormat(tmpl, "999999").str());
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     dw->setString(StringFormat(tmpl, "1000000").str());
     try {
@@ -244,15 +246,15 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
 
     dw->setString(StringFormat(tmpl, "1").str());
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     dw->setString(StringFormat(tmpl, "100").str());
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     dw->setString(StringFormat(tmpl, "999999").str());
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     dw->setString(StringFormat(tmpl, "1000000").str());
     try {
@@ -294,7 +296,7 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
 
     dw->setString(StringFormat(tmpl, "torrent").str());
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     // empty mediatype
     dw->setString(StringFormat(tmpl, "").str());
@@ -317,7 +319,7 @@ void MetalinkProcessorTest::testParseFileV4_attrs()
 
     dw->setString(StringFormat(tmpl, "foo").str());
     m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
 
     // dir traversing
     dw->setString(StringFormat(tmpl, "../doughnuts").str());
@@ -496,8 +498,8 @@ void MetalinkProcessorTest::testParseFile()
   try {
     SharedHandle<Metalinker> metalinker = proc.parseFile("test.xml");
 
-    std::vector<SharedHandle<MetalinkEntry> >::iterator entryItr =
-      metalinker->entries.begin();
+    std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
+      metalinker->getEntries().begin();
 
     SharedHandle<MetalinkEntry> entry1 = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.2.tar.bz2"), entry1->getPath());
@@ -509,7 +511,8 @@ void MetalinkProcessorTest::testParseFile()
 #ifdef ENABLE_MESSAGE_DIGEST
     CPPUNIT_ASSERT_EQUAL(std::string("a96cf3f0266b91d87d5124cf94326422800b627d"),
                          entry1->checksum->getMessageDigest());
-    CPPUNIT_ASSERT_EQUAL(std::string("sha1"), entry1->checksum->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1,
+                         entry1->checksum->getAlgo());
 #endif // ENABLE_MESSAGE_DIGEST
     CPPUNIT_ASSERT(!entry1->getSignature().isNull());
     CPPUNIT_ASSERT_EQUAL(std::string("pgp"), entry1->getSignature()->getType());
@@ -564,7 +567,8 @@ void MetalinkProcessorTest::testParseFile()
                          entry2->chunkChecksum->getChecksum(0));
     CPPUNIT_ASSERT_EQUAL(std::string("fecf8bc9a1647505fe16746f94e97a477597dbf3"),
                          entry2->chunkChecksum->getChecksum(1));
-    CPPUNIT_ASSERT_EQUAL(std::string("sha1"), entry2->checksum->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1,
+                         entry2->checksum->getAlgo());
 #endif // ENABLE_MESSAGE_DIGEST
     // See that signature is null
     CPPUNIT_ASSERT(entry2->getSignature().isNull());
@@ -585,11 +589,11 @@ void MetalinkProcessorTest::testParseFile()
     SharedHandle<MetalinkEntry> entry4 = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("UnsupportedVerificationHashTypeIncluded"), entry4->getPath());
 #ifdef ENABLE_MESSAGE_DIGEST
-    CPPUNIT_ASSERT_EQUAL(std::string("sha1"),
+    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1,
                          entry4->checksum->getAlgo());
     CPPUNIT_ASSERT_EQUAL(std::string("4c255b0ed130f5ea880f0aa061c3da0487e251cc"),
                          entry4->checksum->getMessageDigest());
-    CPPUNIT_ASSERT_EQUAL(std::string("sha1"),
+    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1,
                          entry4->chunkChecksum->getAlgo());
 #endif // ENABLE_MESSAGE_DIGEST
 
@@ -604,8 +608,8 @@ void MetalinkProcessorTest::testParseFile_dirtraversal()
   MetalinkProcessor proc;
   SharedHandle<Metalinker> metalinker =
     proc.parseFile("metalink3-dirtraversal.xml");
-  CPPUNIT_ASSERT_EQUAL((size_t)1, metalinker->entries.size());
-  SharedHandle<MetalinkEntry> e = metalinker->entries[0];
+  CPPUNIT_ASSERT_EQUAL((size_t)1, metalinker->getEntries().size());
+  SharedHandle<MetalinkEntry> e = metalinker->getEntries()[0];
   CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.3.tar.bz2"), e->getPath());
   CPPUNIT_ASSERT(!e->getSignature().isNull());
   CPPUNIT_ASSERT_EQUAL(std::string(""), e->getSignature()->getFile());
@@ -620,8 +624,8 @@ void MetalinkProcessorTest::testParseFromBinaryStream()
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
 
-    std::vector<SharedHandle<MetalinkEntry> >::iterator entryItr =
-      m->entries.begin();
+    std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
+      m->getEntries().begin();
     SharedHandle<MetalinkEntry> entry1 = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.2.tar.bz2"), entry1->getPath());
   } catch(Exception& e) {
@@ -700,8 +704,8 @@ void MetalinkProcessorTest::testBadSize()
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
 
-    std::vector<SharedHandle<MetalinkEntry> >::iterator entryItr =
-      m->entries.begin();
+    std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
+      m->getEntries().begin();
     SharedHandle<MetalinkEntry> e = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.2.tar.bz2"), e->getPath());
     CPPUNIT_ASSERT_EQUAL((uint64_t)0ULL, e->getLength());
@@ -733,8 +737,8 @@ void MetalinkProcessorTest::testBadMaxConn()
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
 
-    std::vector<SharedHandle<MetalinkEntry> >::iterator entryItr =
-      m->entries.begin();
+    std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
+      m->getEntries().begin();
     SharedHandle<MetalinkEntry> e = *entryItr;
     CPPUNIT_ASSERT_EQUAL((uint64_t)43743838ULL, e->getLength());
   } catch(Exception& e) {
@@ -765,9 +769,9 @@ void MetalinkProcessorTest::testNoName()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
-    std::vector<SharedHandle<MetalinkEntry> >::iterator entryItr =
-      m->entries.begin();
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
+    std::vector<SharedHandle<MetalinkEntry> >::const_iterator entryItr =
+      m->getEntries().begin();
     SharedHandle<MetalinkEntry> e = *entryItr;
     CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.5.2.tar.bz2"), e->getPath());
   } catch(Exception& e) {
@@ -796,7 +800,7 @@ void MetalinkProcessorTest::testBadURLPrefs()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<MetalinkResource> r = e->resources[0];
     CPPUNIT_ASSERT_EQUAL(MetalinkResource::TYPE_FTP, r->type);
     CPPUNIT_ASSERT_EQUAL(MetalinkResource::getLowestPriority(), r->priority);
@@ -829,7 +833,7 @@ void MetalinkProcessorTest::testBadURLMaxConn()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<MetalinkResource> r = e->resources[0];
     CPPUNIT_ASSERT_EQUAL(MetalinkResource::TYPE_FTP, r->type);
     CPPUNIT_ASSERT_EQUAL(1, r->priority);
@@ -863,7 +867,7 @@ void MetalinkProcessorTest::testUnsupportedType()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     CPPUNIT_ASSERT_EQUAL((size_t)3, e->resources.size());
     SharedHandle<MetalinkResource> r1 = e->resources[0];
     CPPUNIT_ASSERT_EQUAL(MetalinkResource::TYPE_FTP, r1->type);
@@ -896,10 +900,10 @@ void MetalinkProcessorTest::testMultiplePieces()
   try {
     // aria2 prefers sha1
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<ChunkChecksum> c = e->chunkChecksum;
  
-    CPPUNIT_ASSERT_EQUAL(std::string("sha1"), c->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1, c->getAlgo());
     CPPUNIT_ASSERT_EQUAL((size_t)1024, c->getChecksumLength());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
@@ -929,12 +933,12 @@ void MetalinkProcessorTest::testBadPieceNo()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<ChunkChecksum> c = e->chunkChecksum;
 
     CPPUNIT_ASSERT(!c.isNull());
     CPPUNIT_ASSERT_EQUAL((size_t)1024, c->getChecksumLength());
-    CPPUNIT_ASSERT_EQUAL(std::string("sha1"), c->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1, c->getAlgo());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
@@ -962,12 +966,12 @@ void MetalinkProcessorTest::testBadPieceLength()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<ChunkChecksum> c = e->chunkChecksum;
     CPPUNIT_ASSERT(!c.isNull());
     CPPUNIT_ASSERT_EQUAL((size_t)1024, c->getChecksumLength());
-    CPPUNIT_ASSERT_EQUAL(std::string("sha1"), c->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1, c->getAlgo());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
@@ -995,12 +999,12 @@ void MetalinkProcessorTest::testUnsupportedType_piece()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     SharedHandle<ChunkChecksum> c = e->chunkChecksum;
  
     CPPUNIT_ASSERT(!c.isNull());
     CPPUNIT_ASSERT_EQUAL((size_t)1024, c->getChecksumLength());
-    CPPUNIT_ASSERT_EQUAL(std::string("sha1"), c->getAlgo());
+    CPPUNIT_ASSERT_EQUAL(MessageDigestContext::SHA1, c->getAlgo());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
@@ -1024,7 +1028,7 @@ void MetalinkProcessorTest::testLargeFileSize()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     CPPUNIT_ASSERT_EQUAL((uint64_t)9223372036854775807ULL, e->getLength());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
@@ -1048,8 +1052,8 @@ void MetalinkProcessorTest::testXmlPrefixV3()
 
   try {
     SharedHandle<Metalinker> m = proc.parseFromBinaryStream(dw);
-    CPPUNIT_ASSERT_EQUAL((size_t)1, m->entries.size());
-    SharedHandle<MetalinkEntry> e = m->entries[0];
+    CPPUNIT_ASSERT_EQUAL((size_t)1, m->getEntries().size());
+    SharedHandle<MetalinkEntry> e = m->getEntries()[0];
     CPPUNIT_ASSERT_EQUAL((uint64_t)9223372036854775807ULL, e->getLength());
   } catch(Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
